==> haskell-attoparsec-0.13.2.2-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.2.2
id: attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO
key: attoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
abi: 0245c36a1925390a90499ab600474c70
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/attoparsec-0.13.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/attoparsec-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/attoparsec-0.13.2.2
hs-libraries: HSattoparsec-0.13.2.2-4iFLH0ONEYhG16eDwwtqQO
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 scientific-0.3.6.2-BVEhLkswVxa6jxFFJ9XwaR
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.13.2.2-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.2.2
id: attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay
key: attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
abi: 90b88d59344fd0aefc2727f9d149ad74
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/attoparsec-0.13.2.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/attoparsec-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/attoparsec-0.13.2.2
hs-libraries: HSattoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    deepseq-1.4.4.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
